#
# spec file for package itstool
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           itstool
Version:        2.0.7
Release:        3.1
Summary:        Tool to translate XML documents using PO files
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            http://itstool.org
Source:         http://files.itstool.org/itstool/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM 32c7d07664dc37765100285d1202d488cd6a27e8.patch -- Fix insufficiently quoted regular expressions
Patch:          https://github.com/itstool/itstool/commit/32c7d07664dc37765100285d1202d488cd6a27e8.patch
BuildRequires:  python3-base
BuildArch:      noarch
%if 0%{?sle_version}
BuildRequires:  python3-libxml2-python
Requires:       python3-libxml2-python
%else
BuildRequires:  python3-libxml2
Requires:       python3-libxml2
%endif

%description
ITS Tool extracts messages from XML files and outputs PO template files, then
merges translations from MO files to create translated XML files. It determines
what to translate and how to chunk it into messages using the W3C
Internationalization Tag Set (ITS).

%prep
%autosetup -p1

%build
export PYTHON=$(realpath %{_bindir}/python3)
%configure
%make_build

%install
%make_install PYTHON=$(realpath %{_bindir}/python3)

%files
%license COPYING
%doc ChangeLog NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_mandir}/man1/itstool.1%{?ext_man}

%changelog
* Sun Jun  1 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add 32c7d07664dc37765100285d1202d488cd6a27e8.patch: Fix
  insufficiently quoted regular expressions. These went under the
  radar until Python 3.12 started warning about them.
* Thu Apr 11 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 [bsc#1212476]
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 2.0.7:
  * Performance improvements when chaining up on certain ITS rules
  * Performance improvements when using ITS params.
* Mon Nov 18 2019 Yifan Jiang <yfjiang@suse.com>
- BuildRequires python3-libxml2-python for SLE and Leap 15, which
  are using older version libxml2.
* Tue Sep 17 2019 suse+build@de-korte.org
- Update to version 2.0.6:
  + Make DocBook keyword element within text
  + Apply ITS files passed with -i in --join mode
- Drop itstool-Apply-ITS-files.patch
* Sat Sep 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace python3-libxml2-python with python3-libxml2 BuildRequires
  and Requires following changes in libxml2.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 2.0.5:
  + Allow preserveSpace on XML attributes.
  + Fixed issue with writing files under macOS.
  + Fixed various differences between Python 2 and 3.
  + Fixed issues with libxml2 memory management.
- Add itstool-Apply-ITS-files.patch: Apply ITS files passed with -i
  in --join mode.
- Drop patch itstool-2.0.4-serialize_to_str.patch and
  itstool-2.0.4-memory-management.patch: fixed upstream.
* Wed Jul  4 2018 tchvatal@suse.com
- Switch directly to py3 istool, as it seems it does not break there
  should be no real requirement to use the python2 variant (even on
  old products it should be ok to use py3 one) (bsc#1111019)
* Wed Jun 20 2018 mcepl@suse.com
- Add patch itstool-2.0.4-serialize_to_str.patch
  to fix upstream big #19 (fix str/bytes issue)
- Be consistent in using python%%{_python_ver}
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 13 2018 dimstar@opensuse.org
- Introduce _python_ver variable, currently set to '2': allow for
  an easy way to toggle between python3 and python2 based itstool.
  Currently using python2, as python3-based itstool still has
  issues.
* Tue Oct 24 2017 dimstar@opensuse.org
- Switch to python3 version:
  + Add python3-base BuildRequires: unlike python2, py3 is not
    implicit in the buildroot yet.
  + Export PYTHON=python3 before configure.
  + Replace libxml2-python (Build)?Requires with
    python3-libxml2-python.
- Replace itstool-2.0.4-no-freedoc.patch with
  itstool-2.0.4-memory-management.patch: use upstream provided
  solution for the crshes.
* Tue Oct 24 2017 dimstar@opensuse.org
- Update to version 2.0.4:
  + Fixed a massive performance issue.
- Add itstool-2.0.4-no-freedoc.patch: Do not free xmlDocs, avoid
  crashes (gh#itstool/itstool#17).
* Thu Oct  5 2017 luc14n0@linuxmail.org
- Update to version 2.0.3:
  + Added:
  - Python 3 support. Keeping Python 2 support for now.
  - --path option for extra paths for ITS files.
  + Fixed:
  - --keep-entities mode after some libxml2 changes.
  - UTF-8 handling for translated attributes.
  + Don't error out (except under -s) for mismatched placeholders.
* Tue Dec 24 2013 dimstar@opensuse.org
- Update to version 2.0.2:
  + Fixed crash in locale filter and drop rule (bgo#715116).
  + Don't hardcode python path (fdo#72533).
  + Updated man page.
- Drop itstool-fix-crash.patch: fixed upstream.
- No longer replace the shebang in itstool and itstool.in: the
  upstream provided solution sets it based on configure's findings.
* Mon Nov 25 2013 dimstar@opensuse.org
- Add itstool-fix-crash.patch: Fixed crash in locale filter and
  drop rule (bgo#715116).
* Sun Nov 24 2013 dimstar@opensuse.org
- Update to version 2.0.1:
  + Reworked default ITS rules for better performance.
* Thu Nov  7 2013 dimstar@opensuse.org
- Update to version 2.0.0:
  + Support for ITS 2.0 Preserve Space data category.
  + Support for ITS 2.0 Locale Filter data category.
  + Support for ITS 2.0 External Resource data category.
  + Support for ITS 2.0 ID Value data category.
  + Support for ITS 2.0 parameters, including user overrides.
  + Support for ITS 2.0 local withinText attribute.
  + Fixed handling of localization note inheritance.
  + Fixed handling of namespace prefixes on elements.
  + Added option to retain entity references in PO files.
  + Added option to load external DTDs.
  + Added built-in rules for DocBook 5.
  + Updated built-in rules to use ITS 2.0 Preserve Space and
    External Resource instead of 1.x custom extensions.
  + Excluded editor remarks and comments in built-in DocBook and
    Mallard rules with Locale Filter.
  + Made all DocBook *info children not within text in built-in
    rules.
* Wed Jun 27 2012 dimstar@opensuse.org
- Update to version 1.2.0:
  + Added new "join mode" for multilingual XML formats.
  + Correctly handle ITS version attribute.
  + Better handling of multiple localization notes.
  + XML path markers are now in dedicated comments.
  + Show language code when failing to get translation from PO.
  + Added more regression tests.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 1.1.3:
  + Handle UTF-8 in attribute values
  + Don't output non-translatable external ref messages
  + Better error handling
* Tue Mar  6 2012 coolo@suse.com
- Remove python BuildRequires and %%py_requires: we only need a
  minimal python, which libxml2-python will bring in both cases;
  and we don't need a specific version of python.
* Sun Feb  5 2012 dimstar@opensuse.org
- Update to version 1.1.2:
  + Better handling of XML errors in PO files.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 1.1.1:
  + Catch XML parsing errors and exit with error code
  + Fixed placeholder translation when it contains sub-elements
  + Improved autogen.sh for out of tree compilations
* Tue Jun 28 2011 dimstar@opensuse.org
- Update to version 1.1.0:
  + Added itst:context to set msgctxt
  + Added itst:drop to drop context from translations
  + Allow XML attribute to be translated
  + Allow locNotePointer to return a string
  + Allow localization notes to be space-preserving
  + Allow both XLink and child rules on its:rules
  + Fixed Unicode encoding/decoding errors
  + Added automated test suite
  + Added a man page
  + Python 3 fixes
* Tue May 24 2011 dimstar@opensuse.org
- Initial package, version 1.0.1
